Module create_score_value

Enums

CreateScoreValue
CreateScoreValue : The value of the score. Must be passed as string for categorical scores, and numeric for boolean and numeric scores The value of the score. Must be passed as string for categorical scores, and numeric for boolean and numeric scores